==> freegis-tutorial-html-0.2.zip: freegishtml/internals.pl <==
# LaTeX2HTML 2K.1beta (1.48)
# Associate internals original text with physical files.


$key = q/solved_tasks_de/;
$ref_files{$key} = "$dir".q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_contur_lines_de/;
$ref_files{$key} = "$dir".q|node71.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_bill1/;
$ref_files{$key} = "$dir".q|node217.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_echolot_1/;
$ref_files{$key} = "$dir".q|node46.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_bill2/;
$ref_files{$key} = "$dir".q|node217.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_echolot_2/;
$ref_files{$key} = "$dir".q|node50.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_echolot_3/;
$ref_files{$key} = "$dir".q|node52.html|; 
$noresave{$key} = "$nosave";

$key = q/differential_gps_de/;
$ref_files{$key} = "$dir".q|node134.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:rasterdaten_geokodieren/;
$ref_files{$key} = "$dir".q|node84.html|; 
$noresave{$key} = "$nosave";

$key = q/grass2/;
$ref_files{$key} = "$dir".q|node68.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_volumina_de:grass/;
$ref_files{$key} = "$dir".q|node105.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de:grass/;
$ref_files{$key} = "$dir".q|node81.html|; 
$noresave{$key} = "$nosave";

$key = q/handling_gps_data_de:gpspoint/;
$ref_files{$key} = "$dir".q|node123.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:passpunkte/;
$ref_files{$key} = "$dir".q|node96.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de/;
$ref_files{$key} = "$dir".q|node78.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de:mapit_/;
$ref_files{$key} = "$dir".q|node157.html|; 
$noresave{$key} = "$nosave";

$key = q/g3dgmv_1/;
$ref_files{$key} = "$dir".q|node64.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:dlgv32/;
$ref_files{$key} = "$dir".q|node70.html|; 
$noresave{$key} = "$nosave";

$key = q/fly_over_dem_de:vtpenviro/;
$ref_files{$key} = "$dir".q|node144.html|; 
$noresave{$key} = "$nosave";

$key = q/mapit_1/;
$ref_files{$key} = "$dir".q|node159.html|; 
$noresave{$key} = "$nosave";

$key = q/mapit_2/;
$ref_files{$key} = "$dir".q|node160.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de:dlgv32/;
$ref_files{$key} = "$dir".q|node83.html|; 
$noresave{$key} = "$nosave";

$key = q/mapit_3/;
$ref_files{$key} = "$dir".q|node171.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_greve/;
$ref_files{$key} = "$dir".q|node217.html|; 
$noresave{$key} = "$nosave";

$key = q/used_programms_de/;
$ref_files{$key} = "$dir".q|node15.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de/;
$ref_files{$key} = "$dir".q|node154.html|; 
$noresave{$key} = "$nosave";

$key = q/differential_gps_de:dgpsip/;
$ref_files{$key} = "$dir".q|node137.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_edbs_data_de:grass/;
$ref_files{$key} = "$dir".q|node188.html|; 
$noresave{$key} = "$nosave";

$key = q/future_de/;
$ref_files{$key} = "$dir".q|node203.html|; 
$noresave{$key} = "$nosave";

$key = q/handling_gps_data_de:gpsman/;
$ref_files{$key} = "$dir".q|node129.html|; 
$noresave{$key} = "$nosave";

$key = q/georeferencing_de/;
$ref_files{$key} = "$dir".q|node84.html|; 
$noresave{$key} = "$nosave";

$key = q/tria_3d/;
$ref_files{$key} = "$dir".q|node58.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_hull_label/;
$ref_files{$key} = "$dir".q|node47.html|; 
$noresave{$key} = "$nosave";

$key = q/echolot_gui_1/;
$ref_files{$key} = "$dir".q|node54.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:vtbuilder/;
$ref_files{$key} = "$dir".q|node65.html|; 
$noresave{$key} = "$nosave";

$key = q/contur_1/;
$ref_files{$key} = "$dir".q|node77.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaicking_aerial_images_de:grass/;
$ref_files{$key} = "$dir".q|node114.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:dem3D/;
$ref_files{$key} = "$dir".q|node66.html|; 
$noresave{$key} = "$nosave";

$key = q/echolot_nviz2_wire/;
$ref_files{$key} = "$dir".q|node54.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_volumen_mask_2/;
$ref_files{$key} = "$dir".q|node109.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaik1/;
$ref_files{$key} = "$dir".q|node117.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaik2/;
$ref_files{$key} = "$dir".q|node117.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_edbs_data_de/;
$ref_files{$key} = "$dir".q|node188.html|; 
$noresave{$key} = "$nosave";

$key = q/dlgv32_1/;
$ref_files{$key} = "$dir".q|node70.html|; 
$noresave{$key} = "$nosave";

$key = q/fly_over_dem_de/;
$ref_files{$key} = "$dir".q|node141.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_neteler/;
$ref_files{$key} = "$dir".q|node217.html|; 
$noresave{$key} = "$nosave";

$key = q/georeferencing_de:grass/;
$ref_files{$key} = "$dir".q|node88.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_site_data_de:grass/;
$ref_files{$key} = "$dir".q|node35.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_listen/;
$ref_files{$key} = "$dir".q|node131.html|; 
$noresave{$key} = "$nosave";

$key = q/dem3d_flood/;
$ref_files{$key} = "$dir".q|node82.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_empfaenger/;
$ref_files{$key} = "$dir".q|node130.html|; 
$noresave{$key} = "$nosave";

$key = q/preface_de/;
$ref_files{$key} = "$dir".q|node1.html|; 
$noresave{$key} = "$nosave";

$key = q/vectmap/;
$ref_files{$key} = "$dir".q|node200.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de:mapserver/;
$ref_files{$key} = "$dir".q|node172.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:g3dgmv/;
$ref_files{$key} = "$dir".q|node63.html|; 
$noresave{$key} = "$nosave";

$key = q/vtbuilder_1/;
$ref_files{$key} = "$dir".q|node65.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_volumen_1/;
$ref_files{$key} = "$dir".q|node106.html|; 
$noresave{$key} = "$nosave";

$key = q/vtbuilder_2/;
$ref_files{$key} = "$dir".q|node65.html|; 
$noresave{$key} = "$nosave";

$key = q/free_geo_data_de/;
$ref_files{$key} = "$dir".q|node27.html|; 
$noresave{$key} = "$nosave";

$key = q/handling_gps_data_de/;
$ref_files{$key} = "$dir".q|node120.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de/;
$ref_files{$key} = "$dir".q|node59.html|; 
$noresave{$key} = "$nosave";

$key = q/credits_de/;
$ref_files{$key} = "$dir".q|node4.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Digitalisierung_am_Bildschirm/;
$ref_files{$key} = "$dir".q|node107.html|; 
$noresave{$key} = "$nosave";

$key = q/used_data_de/;
$ref_files{$key} = "$dir".q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/enviro_1/;
$ref_files{$key} = "$dir".q|node144.html|; 
$noresave{$key} = "$nosave";

$key = q/enviro_2/;
$ref_files{$key} = "$dir".q|node146.html|; 
$noresave{$key} = "$nosave";

$key = q/fly_over_dem_de:grass/;
$ref_files{$key} = "$dir".q|node147.html|; 
$noresave{$key} = "$nosave";

$key = q/enviro_3/;
$ref_files{$key} = "$dir".q|node146.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_hauptfenster/;
$ref_files{$key} = "$dir".q|node131.html|; 
$noresave{$key} = "$nosave";

$key = q/gnufdl_en/;
$ref_files{$key} = "$dir".q|node204.html|; 
$noresave{$key} = "$nosave";

$key = q/delaunay_1/;
$ref_files{$key} = "$dir".q|node58.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de:dem3d/;
$ref_files{$key} = "$dir".q|node82.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaik_ipoints/;
$ref_files{$key} = "$dir".q|node116.html|; 
$noresave{$key} = "$nosave";

$key = q/grassflood_1/;
$ref_files{$key} = "$dir".q|node81.html|; 
$noresave{$key} = "$nosave";

$key = q/dlgv32flood/;
$ref_files{$key} = "$dir".q|node83.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de:mapserver:include_contur_lines/;
$ref_files{$key} = "$dir".q|node182.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:maskierung/;
$ref_files{$key} = "$dir".q|node106.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_contur_lines_de:grass/;
$ref_files{$key} = "$dir".q|node75.html|; 
$noresave{$key} = "$nosave";

$key = q/rastmap/;
$ref_files{$key} = "$dir".q|node200.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_site_data_de/;
$ref_files{$key} = "$dir".q|node31.html|; 
$noresave{$key} = "$nosave";

$key = q/echolot_nviz2_3d/;
$ref_files{$key} = "$dir".q|node54.html|; 
$noresave{$key} = "$nosave";

$key = q/triangulate_site_data_de/;
$ref_files{$key} = "$dir".q|node55.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_volumina_de/;
$ref_files{$key} = "$dir".q|node102.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_echtzeit/;
$ref_files{$key} = "$dir".q|node132.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_1/;
$ref_files{$key} = "$dir".q|node99.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_2/;
$ref_files{$key} = "$dir".q|node99.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_3/;
$ref_files{$key} = "$dir".q|node101.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_4/;
$ref_files{$key} = "$dir".q|node101.html|; 
$noresave{$key} = "$nosave";

$key = q/dem3d_1/;
$ref_files{$key} = "$dir".q|node66.html|; 
$noresave{$key} = "$nosave";

$key = q/converting_data_de/;
$ref_files{$key} = "$dir".q|node201.html|; 
$noresave{$key} = "$nosave";

$key = q/dem3d_2/;
$ref_files{$key} = "$dir".q|node66.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_echtzeitnmea/;
$ref_files{$key} = "$dir".q|node132.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_1/;
$ref_files{$key} = "$dir".q|node108.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_2/;
$ref_files{$key} = "$dir".q|node108.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_3/;
$ref_files{$key} = "$dir".q|node108.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_4/;
$ref_files{$key} = "$dir".q|node108.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_1/;
$ref_files{$key} = "$dir".q|node174.html|; 
$noresave{$key} = "$nosave";

$key = q/triangulate_site_data_de:grass/;
$ref_files{$key} = "$dir".q|node58.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_2/;
$ref_files{$key} = "$dir".q|node177.html|; 
$noresave{$key} = "$nosave";

$key = q/intro_de/;
$ref_files{$key} = "$dir".q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_3/;
$ref_files{$key} = "$dir".q|node178.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaicking_aerial_images_de/;
$ref_files{$key} = "$dir".q|node111.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_4/;
$ref_files{$key} = "$dir".q|node186.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_5/;
$ref_files{$key} = "$dir".q|node182.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:grass/;
$ref_files{$key} = "$dir".q|node67.html|; 
$noresave{$key} = "$nosave";

1;

==> freegis-tutorial-html-0.5.zip: freegishtml/internals.pl <==
# LaTeX2HTML 99.2beta8 (1.43)
# Associate internals original text with physical files.


$key = q/solved_tasks_de/;
$ref_files{$key} = "$dir".q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_contur_lines_de/;
$ref_files{$key} = "$dir".q|node66.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_bill1/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_echolot_1/;
$ref_files{$key} = "$dir".q|node40.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_bill2/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_echolot_2/;
$ref_files{$key} = "$dir".q|node45.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_echolot_3/;
$ref_files{$key} = "$dir".q|node47.html|; 
$noresave{$key} = "$nosave";

$key = q/differential_gps_de/;
$ref_files{$key} = "$dir".q|node138.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:rasterdaten_geokodieren/;
$ref_files{$key} = "$dir".q|node81.html|; 
$noresave{$key} = "$nosave";

$key = q/grass2/;
$ref_files{$key} = "$dir".q|node63.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_voser/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_volumina_de:grass/;
$ref_files{$key} = "$dir".q|node101.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de:grass/;
$ref_files{$key} = "$dir".q|node77.html|; 
$noresave{$key} = "$nosave";

$key = q/handling_gps_data_de:gpspoint/;
$ref_files{$key} = "$dir".q|node126.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:passpunkte/;
$ref_files{$key} = "$dir".q|node92.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de/;
$ref_files{$key} = "$dir".q|node74.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de:mapit_/;
$ref_files{$key} = "$dir".q|node162.html|; 
$noresave{$key} = "$nosave";

$key = q/g3dgmv_1/;
$ref_files{$key} = "$dir".q|node59.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:dlgv32/;
$ref_files{$key} = "$dir".q|node65.html|; 
$noresave{$key} = "$nosave";

$key = q/fly_over_dem_de:vtpenviro/;
$ref_files{$key} = "$dir".q|node148.html|; 
$noresave{$key} = "$nosave";

$key = q/mapit_1/;
$ref_files{$key} = "$dir".q|node164.html|; 
$noresave{$key} = "$nosave";

$key = q/mapit_2/;
$ref_files{$key} = "$dir".q|node165.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de:dlgv32/;
$ref_files{$key} = "$dir".q|node80.html|; 
$noresave{$key} = "$nosave";

$key = q/mapit_3/;
$ref_files{$key} = "$dir".q|node176.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_greve/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/used_programms_de/;
$ref_files{$key} = "$dir".q|node12.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de/;
$ref_files{$key} = "$dir".q|node159.html|; 
$noresave{$key} = "$nosave";

$key = q/differential_gps_de:dgpsip/;
$ref_files{$key} = "$dir".q|node141.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_edbs_data_de:grass/;
$ref_files{$key} = "$dir".q|node193.html|; 
$noresave{$key} = "$nosave";

$key = q/future_de/;
$ref_files{$key} = "$dir".q|node204.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_rothacher_zebhauser/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/georeferencing_de/;
$ref_files{$key} = "$dir".q|node81.html|; 
$noresave{$key} = "$nosave";

$key = q/handling_gps_data_de:gpsman/;
$ref_files{$key} = "$dir".q|node132.html|; 
$noresave{$key} = "$nosave";

$key = q/tria_3d/;
$ref_files{$key} = "$dir".q|node53.html|; 
$noresave{$key} = "$nosave";

$key = q/echolot_gui_1/;
$ref_files{$key} = "$dir".q|node49.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_hull_label/;
$ref_files{$key} = "$dir".q|node41.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_omc/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:vtbuilder/;
$ref_files{$key} = "$dir".q|node60.html|; 
$noresave{$key} = "$nosave";

$key = q/contur_1/;
$ref_files{$key} = "$dir".q|node73.html|; 
$noresave{$key} = "$nosave";

$key = q/contur_2/;
$ref_files{$key} = "$dir".q|node73.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_m_nz/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaicking_aerial_images_de:grass/;
$ref_files{$key} = "$dir".q|node110.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:dem3D/;
$ref_files{$key} = "$dir".q|node61.html|; 
$noresave{$key} = "$nosave";

$key = q/echolot_nviz2_wire/;
$ref_files{$key} = "$dir".q|node49.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_volumen_mask_2/;
$ref_files{$key} = "$dir".q|node105.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaik1/;
$ref_files{$key} = "$dir".q|node121.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaik2/;
$ref_files{$key} = "$dir".q|node121.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_edbs_data_de/;
$ref_files{$key} = "$dir".q|node193.html|; 
$noresave{$key} = "$nosave";

$key = q/dlgv32_1/;
$ref_files{$key} = "$dir".q|node65.html|; 
$noresave{$key} = "$nosave";

$key = q/fly_over_dem_de/;
$ref_files{$key} = "$dir".q|node145.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_neteler/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/georeferencing_de:grass/;
$ref_files{$key} = "$dir".q|node85.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_site_data_de:grass/;
$ref_files{$key} = "$dir".q|node28.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_listen/;
$ref_files{$key} = "$dir".q|node135.html|; 
$noresave{$key} = "$nosave";

$key = q/dem3d_flood/;
$ref_files{$key} = "$dir".q|node79.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_empfaenger/;
$ref_files{$key} = "$dir".q|node134.html|; 
$noresave{$key} = "$nosave";

$key = q/marks1/;
$ref_files{$key} = "$dir".q|node115.html|; 
$noresave{$key} = "$nosave";

$key = q/marks2/;
$ref_files{$key} = "$dir".q|node115.html|; 
$noresave{$key} = "$nosave";

$key = q/preface_de/;
$ref_files{$key} = "$dir".q|node1.html|; 
$noresave{$key} = "$nosave";

$key = q/vectmap/;
$ref_files{$key} = "$dir".q|node203.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de:mapserver/;
$ref_files{$key} = "$dir".q|node177.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:g3dgmv/;
$ref_files{$key} = "$dir".q|node58.html|; 
$noresave{$key} = "$nosave";

$key = q/vtbuilder_1/;
$ref_files{$key} = "$dir".q|node60.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_volumen_1/;
$ref_files{$key} = "$dir".q|node102.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_herrmann/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/vtbuilder_2/;
$ref_files{$key} = "$dir".q|node60.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_mitasova/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/handling_gps_data_de/;
$ref_files{$key} = "$dir".q|node123.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de/;
$ref_files{$key} = "$dir".q|node54.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_barnes/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Digitalisierung_am_Bildschirm/;
$ref_files{$key} = "$dir".q|node103.html|; 
$noresave{$key} = "$nosave";

$key = q/credits_de/;
$ref_files{$key} = "$dir".q|node3.html|; 
$noresave{$key} = "$nosave";

$key = q/used_data_de/;
$ref_files{$key} = "$dir".q|node11.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_cadglossar/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_commando/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/enviro_1/;
$ref_files{$key} = "$dir".q|node148.html|; 
$noresave{$key} = "$nosave";

$key = q/enviro_2/;
$ref_files{$key} = "$dir".q|node150.html|; 
$noresave{$key} = "$nosave";

$key = q/fly_over_dem_de:grass/;
$ref_files{$key} = "$dir".q|node151.html|; 
$noresave{$key} = "$nosave";

$key = q/enviro_3/;
$ref_files{$key} = "$dir".q|node150.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_hauptfenster/;
$ref_files{$key} = "$dir".q|node135.html|; 
$noresave{$key} = "$nosave";

$key = q/gnufdl_en/;
$ref_files{$key} = "$dir".q|node205.html|; 
$noresave{$key} = "$nosave";

$key = q/delaunay_1/;
$ref_files{$key} = "$dir".q|node53.html|; 
$noresave{$key} = "$nosave";

$key = q/flood_model_de:dem3d/;
$ref_files{$key} = "$dir".q|node79.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaik_ipoints/;
$ref_files{$key} = "$dir".q|node120.html|; 
$noresave{$key} = "$nosave";

$key = q/grassflood_1/;
$ref_files{$key} = "$dir".q|node77.html|; 
$noresave{$key} = "$nosave";

$key = q/dlgv32flood/;
$ref_files{$key} = "$dir".q|node80.html|; 
$noresave{$key} = "$nosave";

$key = q/web_mapping_de:mapserver:include_contur_lines/;
$ref_files{$key} = "$dir".q|node187.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:maskierung/;
$ref_files{$key} = "$dir".q|node102.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_contur_lines_de:grass/;
$ref_files{$key} = "$dir".q|node70.html|; 
$noresave{$key} = "$nosave";

$key = q/rastmap/;
$ref_files{$key} = "$dir".q|node203.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_site_data_de/;
$ref_files{$key} = "$dir".q|node24.html|; 
$noresave{$key} = "$nosave";

$key = q/echolot_nviz2_3d/;
$ref_files{$key} = "$dir".q|node49.html|; 
$noresave{$key} = "$nosave";

$key = q/triangulate_site_data_de/;
$ref_files{$key} = "$dir".q|node50.html|; 
$noresave{$key} = "$nosave";

$key = q/computing_volumina_de/;
$ref_files{$key} = "$dir".q|node98.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_hildebrandt/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_echtzeit/;
$ref_files{$key} = "$dir".q|node136.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_1/;
$ref_files{$key} = "$dir".q|node95.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_2/;
$ref_files{$key} = "$dir".q|node95.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_3/;
$ref_files{$key} = "$dir".q|node97.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_georef_4/;
$ref_files{$key} = "$dir".q|node97.html|; 
$noresave{$key} = "$nosave";

$key = q/dem3d_1/;
$ref_files{$key} = "$dir".q|node61.html|; 
$noresave{$key} = "$nosave";

$key = q/dem3d_2/;
$ref_files{$key} = "$dir".q|node61.html|; 
$noresave{$key} = "$nosave";

$key = q/gpsman_echtzeitnmea/;
$ref_files{$key} = "$dir".q|node136.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_1/;
$ref_files{$key} = "$dir".q|node104.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_2/;
$ref_files{$key} = "$dir".q|node104.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_appelrath/;
$ref_files{$key} = "$dir".q|node218.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_3/;
$ref_files{$key} = "$dir".q|node104.html|; 
$noresave{$key} = "$nosave";

$key = q/grass_mask_digit_4/;
$ref_files{$key} = "$dir".q|node104.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_1/;
$ref_files{$key} = "$dir".q|node179.html|; 
$noresave{$key} = "$nosave";

$key = q/triangulate_site_data_de:grass/;
$ref_files{$key} = "$dir".q|node53.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_2/;
$ref_files{$key} = "$dir".q|node182.html|; 
$noresave{$key} = "$nosave";

$key = q/intro_de/;
$ref_files{$key} = "$dir".q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_3/;
$ref_files{$key} = "$dir".q|node183.html|; 
$noresave{$key} = "$nosave";

$key = q/mosaicking_aerial_images_de/;
$ref_files{$key} = "$dir".q|node107.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_4/;
$ref_files{$key} = "$dir".q|node191.html|; 
$noresave{$key} = "$nosave";

$key = q/mapserver_5/;
$ref_files{$key} = "$dir".q|node187.html|; 
$noresave{$key} = "$nosave";

$key = q/import_usgs_dem_de:grass/;
$ref_files{$key} = "$dir".q|node62.html|; 
$noresave{$key} = "$nosave";

1;
